@@ -29,6 +29,7 @@ class Module(AuxDataContainer):
         currently exist or have the same contents.
     :ivar ~.isa: The ISA of the binary.
     :ivar ~.file_format: The file format of the binary.
+    :ivar ~.byte_order: The endianness of the binary.
     :ivar ~.name: The name given to the binary. Some file formats use this
         for linking and/or symbol resolution purposes. The file name (without
         directory components) if not specified by the format.
@@ -122,6 +123,19 @@ class Module(AuxDataContainer):
         ValidButUnsupported = Module_pb2.ISA.Value("ValidButUnsupported")
         """An unknown or undefined ISA."""
 
+    class ByteOrder(Enum):
+        """Identifies the endianness of a :class:`gtirb.Module`.
+        """
+
+        Undefined = Module_pb2.ByteOrder.Value("ByteOrder_Undefined")
+        """An unknown or uninitialized endianness."""
+
+        Big = Module_pb2.ByteOrder.Value("BigEndian")
+        """Big endian."""
+
+        Little = Module_pb2.ByteOrder.Value("LittleEndian")
+        """Little endian."""
+
     class _NodeSet(SetWrapper):
         def __init__(self, node, field, *args):
             self._node = node  # type: Module
@@ -152,6 +166,7 @@ class Module(AuxDataContainer):
         binary_path="",  # type: str
         file_format=FileFormat.Undefined,  # type: Module.FileFormat
         isa=ISA.Undefined,  # type: Module.ISA
+        byte_order=ByteOrder.Undefined,  # type: Module.ByteOrder
         preferred_addr=0,  # type: int
         proxies=set(),  # type: typing.Iterable[ProxyBlock]
         rebase_delta=0,  # type: int
@@ -168,6 +183,7 @@ class Module(AuxDataContainer):
         :param binary_path: The path to the loadable binary object
             represented by this module.
         :param isa: The ISA of the binary.
+        :param byte_order: The endianness of the binary.
         :param file_format: The file format of the binary.
         :param name: The name given to the binary.
         :param preferred_addr: The preferred loading address of the binary.
@@ -188,6 +204,7 @@ class Module(AuxDataContainer):
         self._ir = None  # type: "IR"
         self.binary_path = binary_path  # type: str
         self.isa = isa  # type: Module.ISA
+        self.byte_order = byte_order  # type: Module.ByteOrder
         self.file_format = file_format  # type: Module.FileFormat
         self.name = name  # type: str
         self.preferred_addr = preferred_addr  # type: int
@@ -215,6 +232,7 @@ class Module(AuxDataContainer):
             name=proto_module.name,
             preferred_addr=proto_module.preferred_addr,
             rebase_delta=proto_module.rebase_delta,
+            byte_order=Module.ByteOrder(proto_module.byte_order),
             uuid=uuid,
         )
         m._add_to_uuid_cache(ir._local_uuid_cache)
@@ -264,6 +282,7 @@ class Module(AuxDataContainer):
         proto_module.symbols.extend(s._to_protobuf() for s in self.symbols)
         if self.entry_point is not None:
             proto_module.entry_point = self.entry_point.uuid.bytes
+        proto_module.byte_order = self.byte_order.value
         proto_module.uuid = self.uuid.bytes
         return proto_module
 
@@ -277,6 +296,7 @@ class Module(AuxDataContainer):
         for attr in (
             "binary_path",
             "isa",
+            "byte_order",
             "file_format",
             "name",
             "preferred_addr",
@@ -311,6 +331,7 @@ class Module(AuxDataContainer):
             "name={name!r}, "
             "binary_path={binary_path!r}, "
             "isa=Module.{isa!s}, "
+            "byte_order=Module.{byte_order!s}, "
             "file_format=Module.{file_format!s}, "
             "preferred_addr={preferred_addr:#x}, "
             "rebase_delta={rebase_delta:#x}, "
